@@ -30,11 +30,7 @@ use Test::Builder;
 	file_mtime_gt_ok file_mtime_lt_ok file_mtime_age_ok
 	);
 
-$VERSION = '1.443_01';
-
-{
-use warnings;
-}
+$VERSION = '1.443_02';
 
 my $Test = Test::Builder->new();
 
@@ -73,8 +69,7 @@ generated.
 
 =cut
 
-sub _normalize
-	{
+sub _normalize {
 	my $file = shift;
 	return unless defined $file;
 
@@ -83,8 +78,7 @@ sub _normalize
 		: $file;
 	}
 
-sub _win32
-	{
+sub _win32 {
 	return 0 if $^O eq 'darwin';
 	return $ENV{PRETEND_TO_BE_WIN32} if defined $ENV{PRETEND_TO_BE_WIN32};
 	return $^O =~ m/Win/;
@@ -98,8 +92,7 @@ sub _no_symlinks_here { ! eval { symlink("",""); 1 } }
 # to skip on the two OS's that I KNOW aren't multi-user.  I'd love to add
 # more if anyone knows of any
 #   Note:  I don't have a dos or mac os < 10 machine to test this on
-sub _obviously_non_multi_user
-	{
+sub _obviously_non_multi_user {
 	foreach my $os ( qw(dos MacOS) ) { return 1 if $^O eq $os }
 
 	return 0 if $^O eq 'MSWin32';
@@ -121,19 +114,16 @@ Ok if the file exists, and not ok otherwise.
 
 =cut
 
-sub file_exists_ok
-	{
+sub file_exists_ok {
 	my $filename = _normalize( shift );
 	my $name     = shift || "$filename exists";
 
 	my $ok = -e $filename;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag("File [$filename] does not exist");
 		$Test->ok(0, $name);
 		}
@@ -145,19 +135,16 @@ Ok if the file does not exist, and not okay if it does exist.
 
 =cut
 
-sub file_not_exists_ok
-	{
+sub file_not_exists_ok {
 	my $filename = _normalize( shift );
 	my $name     = shift || "$filename does not exist";
 
 	my $ok = not -e $filename;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag("File [$filename] exists");
 		$Test->ok(0, $name);
 		}
@@ -168,27 +155,30 @@ sub file_not_exists_ok
 Ok if the file exists and has empty size, not ok if the
 file does not exist or exists with non-zero size.
 
+Previously this tried to test any sort of file. Sometime in the future
+this will fail if the argument is not a plain file.
+
 =cut
 
-sub file_empty_ok
-	{
+sub file_empty_ok {
 	my $filename = _normalize( shift );
 	my $name     = shift || "$filename is empty";
 
-	unless( -e $filename )
-		{
+	unless( -e $filename ) {
 		$Test->diag( "File [$filename] does not exist!" );
 		return $Test->ok(0, $name);
 		}
 
+	unless( -f $filename ) {
+		$Test->diag( "File [$filename] is not a plain file, which is deprecated for file_empty_ok" );
+		}
+
 	my $ok = -z $filename;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag( "File [$filename] exists with non-zero size!" );
 		$Test->ok(0, $name);
 		}
@@ -196,30 +186,33 @@ sub file_empty_ok
 
 =item file_not_empty_ok( FILENAME [, NAME ] )
 
-Ok if the file exists and has non-zero size, not ok if the
-file does not exist or exists with zero size.
+Ok if the file exists and has non-zero size, not ok if the file does
+not exist or exists with zero size.
+
+Previously this tried to test any sort of file. Sometime in the future
+this will fail if the argument is not a plain file.
 
 =cut
 
-sub file_not_empty_ok
-	{
+sub file_not_empty_ok {
 	my $filename = _normalize( shift );
 	my $name     = shift || "$filename is not empty";
 
-	unless( -e $filename )
-		{
+	unless( -e $filename ) {
 		$Test->diag( "File [$filename] does not exist!" );
 		return $Test->ok(0, $name);
 		}
 
+	unless( -f $filename ) {
+		$Test->diag( "File [$filename] is a directory, which is deprecated for file_not_empty_ok" );
+		}
+
 	my $ok = not -z _;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag( "File [$filename] exists with zero size!" );
 		$Test->ok(0, $name);
 		}
@@ -230,28 +223,31 @@ sub file_not_empty_ok
 Ok if the file exists and has SIZE size in bytes (exactly), not ok if
 the file does not exist or exists with size other than SIZE.
 
+Previously this tried to test any sort of file. Sometime in the future
+this will fail if the argument is not a plain file.
+
 =cut
 
-sub file_size_ok
-	{
+sub file_size_ok {
 	my $filename = _normalize( shift );
 	my $expected = int shift;
 	my $name     = shift || "$filename has right size";
 
-	unless( -e $filename )
-		{
+	unless( -e $filename ) {
 		$Test->diag( "File [$filename] does not exist!" );
 		return $Test->ok(0, $name);
 		}
 
+	unless( -f $filename ) {
+		$Test->diag( "File [$filename] is a directory, which is deprecated for file_size_ok" );
+		}
+
 	my $ok = ( -s $filename ) == $expected;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		my $actual = -s $filename;
 		$Test->diag(
 			"File [$filename] has actual size [$actual] not [$expected]!" );
@@ -266,28 +262,31 @@ Ok if the file exists and has size less than or equal to MAX bytes, not
 ok if the file does not exist or exists with size greater than MAX
 bytes.
 
+Previously this tried to test any sort of file. Sometime in the future
+this will fail if the argument is not a plain file.
+
 =cut
 
-sub file_max_size_ok
-	{
+sub file_max_size_ok {
 	my $filename = _normalize( shift );
 	my $max      = int shift;
 	my $name     = shift || "$filename is under $max bytes";
 
-	unless( -e $filename )
-		{
+	unless( -e $filename ) {
 		$Test->diag( "File [$filename] does not exist!" );
 		return $Test->ok(0, $name);
 		}
 
+	unless( -f $filename ) {
+		$Test->diag( "File [$filename] is a directory, which is deprecated for file_max_size_ok" );
+		}
+
 	my $ok = ( -s $filename ) <= $max;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		my $actual = -s $filename;
 		$Test->diag(
 			"File [$filename] has actual size [$actual] " .
@@ -304,28 +303,31 @@ Ok if the file exists and has size greater than or equal to MIN bytes,
 not ok if the file does not exist or exists with size less than MIN
 bytes.
 
+Previously this tried to test any sort of file. Sometime in the future
+this will fail if the argument is not a plain file.
+
 =cut
 
-sub file_min_size_ok
-	{
+sub file_min_size_ok {
 	my $filename = _normalize( shift );
 	my $min      = int shift;
 	my $name     = shift || "$filename is over $min bytes";
 
-	unless( -e $filename )
-		{
+	unless( -e $filename ) {
 		$Test->diag( "File [$filename] does not exist!" );
 		return $Test->ok(0, $name);
 		}
 
+	unless( -f $filename ) {
+		$Test->diag( "File [$filename] is a directory, which is deprecated for file_min_size_ok" );
+		}
+
 	my $ok = ( -s $filename ) >= $min;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		my $actual = -s $filename;
 		$Test->diag(
 			"File [$filename] has actual size ".
@@ -344,17 +346,20 @@ file does not exist or exists with a line count other than COUNT.
 This function uses the current value of C<$/> as the line ending and
 counts the lines by reading them and counting how many it read.
 
+Previously this tried to test any sort of file. Sometime in the future
+this will fail if the argument is not a plain file.
+
 =cut
 
 sub _ENOFILE   () { -1 }
 sub _ECANTOPEN () { -2 }
+sub _ENOTPLAIN () { -3 }
 
-sub _file_line_counter
-	{
+sub _file_line_counter {
 	my $filename = shift;
 
-	return _ENOFILE   unless -e $filename;  # does not exist
-
+	return _ENOFILE   unless -e $filename;
+	return _ENOTPLAIN unless -f $filename;
 	return _ECANTOPEN unless open my( $fh ), "<", $filename;
 
 	my $count = 0;
@@ -365,8 +370,7 @@ sub _file_line_counter
 
 # XXX: lots of cut and pasting here, needs refactoring
 # looks like the refactoring might be worse than this though
-sub file_line_count_is
-	{
+sub file_line_count_is {
 	my $filename = _normalize( shift );
 	my $expected = shift;
 	my $name     = do {
@@ -374,8 +378,7 @@ sub file_line_count_is
 		shift || "$filename line count is $expected lines";
 		};
 
-	unless( defined $expected && int( $expected ) == $expected )
-		{
+	unless( defined $expected && int( $expected ) == $expected ) {
 		no warnings 'uninitialized';
 		$Test->diag( "file_line_count_is expects a positive whole number for " .
 			"the second argument. Got [$expected]!" );
@@ -384,22 +387,22 @@ sub file_line_count_is
 
 	my $got = _file_line_counter( $filename );
 
-	if( $got eq _ENOFILE )
-		{
+	if( $got eq _ENOFILE ) {
 		$Test->diag( "File [$filename] does not exist!" );
 		$Test->ok( 0, $name );
 		}
-	elsif( $got == _ECANTOPEN )
-		{
+	elsif( $got eq _ENOTPLAIN ) {
+		$Test->diag( "File [$filename] is not a plain file!" );
+		$Test->ok( 0, $name );
+		}
+	elsif( $got == _ECANTOPEN ) {
 		$Test->diag( "Could not open [$filename]: \$! is [$!]!" );
 		$Test->ok( 0, $name );
 		}
-	elsif( $got == $expected )
-		{
+	elsif( $got == $expected ) {
 		$Test->ok( 1, $name );
 		}
-	else
-		{
+	else {
 		$Test->diag( "Expected [$expected] lines in [$filename], " .
 			"got [$got] lines!" );
 		$Test->ok( 0, $name );
@@ -409,17 +412,19 @@ sub file_line_count_is
 
 =item file_line_count_isnt( FILENAME, COUNT [, NAME ]  )
 
-Ok if the file exists and doesn't have exactly COUNT lines, not ok if the
-file does not exist or exists with a line count of COUNT. Read that
-carefully: the file must exist for this test to pass!
+Ok if the file exists and doesn't have exactly COUNT lines, not ok if
+the file does not exist or exists with a line count of COUNT. Read
+that carefully: the file must exist for this test to pass!
 
 This function uses the current value of C<$/> as the line ending and
 counts the lines by reading them and counting how many it read.
 
+Previously this tried to test any sort of file. Sometime in the future
+this will fail if the argument is not a plain file.
+
 =cut
 
-sub file_line_count_isnt
-	{
+sub file_line_count_isnt {
 	my $filename = _normalize( shift );
 	my $expected = shift;
 	my $name     = do {
@@ -427,8 +432,7 @@ sub file_line_count_isnt
 		shift || "$filename line count is not $expected lines";
 		};
 
-	unless( defined $expected && int( $expected ) == $expected )
-		{
+	unless( defined $expected && int( $expected ) == $expected ) {
 		no warnings 'uninitialized';
 		$Test->diag( "file_line_count_is expects a positive whole number for " .
 			"the second argument. Got [$expected]!" );
@@ -437,22 +441,22 @@ sub file_line_count_isnt
 
 	my $got = _file_line_counter( $filename );
 
-	if( $got eq _ENOFILE )
-		{
+	if( $got eq _ENOFILE ) {
 		$Test->diag( "File [$filename] does not exist!" );
 		$Test->ok( 0, $name );
 		}
-	elsif( $got == _ECANTOPEN )
-		{
+	elsif( $got eq _ENOTPLAIN ) {
+		$Test->diag( "File [$filename] is not a plain file!" );
+		$Test->ok( 0, $name );
+		}
+	elsif( $got == _ECANTOPEN ) {
 		$Test->diag( "Could not open [$filename]: \$! is [$!]!" );
 		$Test->ok( 0, $name );
 		}
-	elsif( $got != $expected )
-		{
+	elsif( $got != $expected ) {
 		$Test->ok( 1, $name );
 		}
-	else
-		{
+	else {
 		$Test->diag( "Expected something other than [$expected] lines in [$filename], " .
 			"but got [$got] lines!" );
 		$Test->ok( 0, $name );
@@ -462,15 +466,18 @@ sub file_line_count_isnt
 
 =item file_line_count_between( FILENAME, MIN, MAX, [, NAME ]  )
 
-Ok if the file exists and has a line count between MIN and MAX, inclusively.
+Ok if the file exists and has a line count between MIN and MAX,
+inclusively.
 
 This function uses the current value of C<$/> as the line ending and
 counts the lines by reading them and counting how many it read.
 
+Previously this tried to test any sort of file. Sometime in the future
+this will fail if the argument is not a plain file.
+
 =cut
 
-sub file_line_count_between
-	{
+sub file_line_count_between {
 	my $filename = _normalize( shift );
 	my $min      = shift;
 	my $max      = shift;
@@ -480,10 +487,8 @@ sub file_line_count_between
 		shift || "$filename line count is between [$min] and [$max] lines";
 		};
 
-	foreach my $ref ( \$min, \$max )
-		{
-		unless( defined $$ref && int( $$ref ) == $$ref )
-			{
+	foreach my $ref ( \$min, \$max ) {
+		unless( defined $$ref && int( $$ref ) == $$ref ) {
 			no warnings 'uninitialized';
 			$Test->diag( "file_line_count_between expects positive whole numbers for " .
 				"the second and third arguments. Got [$min] and [$max]!" );
@@ -491,31 +496,29 @@ sub file_line_count_between
 			}
 		}
 
-
 	my $got = _file_line_counter( $filename );
 
-	if( $got eq _ENOFILE )
-		{
+	if( $got eq _ENOFILE ) {
 		$Test->diag( "File [$filename] does not exist!" );
 		$Test->ok( 0, $name );
 		}
-	elsif( $got == _ECANTOPEN )
-		{
+	elsif( $got eq _ENOTPLAIN ) {
+		$Test->diag( "File [$filename] is not a plain file!" );
+		$Test->ok( 0, $name );
+		}
+	elsif( $got == _ECANTOPEN ) {
 		$Test->diag( "Could not open [$filename]: \$! is [$!]!" );
 		$Test->ok( 0, $name );
 		}
-	elsif( $min <= $got and $got <= $max )
-		{
+	elsif( $min <= $got and $got <= $max ) {
 		$Test->ok( 1, $name );
 		}
-	else
-		{
+	else {
 		$Test->diag( "Expected a line count between [$min] and [$max] " .
 			"in [$filename], but got [$got] lines!"
 			);
 		$Test->ok( 0, $name );
 		}
-
 	}
 
 =item file_contains_like ( FILENAME, PATTERN [, NAME ] )
@@ -593,46 +596,41 @@ The same as C<file_contains_unlike>, except the file is opened with ENCODING.
 
 =cut
 
-sub file_contains_like
-	{
-		local $Test::Builder::Level = $Test::Builder::Level + 1;
-		_file_contains(like => "contains", undef, @_);
+sub file_contains_like {
+	local $Test::Builder::Level = $Test::Builder::Level + 1;
+	_file_contains(like => "contains", undef, @_);
 	}
 
-sub file_contains_unlike
-	{
-		local $Test::Builder::Level = $Test::Builder::Level + 1;
-		_file_contains(unlike => "doesn't contain", undef, @_);
+sub file_contains_unlike {
+	local $Test::Builder::Level = $Test::Builder::Level + 1;
+	_file_contains(unlike => "doesn't contain", undef, @_);
 	}
 
-sub file_contains_utf8_like
-	{
-		local $Test::Builder::Level = $Test::Builder::Level + 1;
-		_file_contains(like => "contains", 'UTF-8', @_);
-	}
-sub file_contains_utf8_unlike
-	{
-		local $Test::Builder::Level = $Test::Builder::Level + 1;
-		_file_contains(unlike => "doesn't contain", 'UTF-8', @_);
+sub file_contains_utf8_like {
+	local $Test::Builder::Level = $Test::Builder::Level + 1;
+	_file_contains(like => "contains", 'UTF-8', @_);
 	}
 
-sub file_contains_encoded_like
-	{
-		local $Test::Builder::Level = $Test::Builder::Level + 1;
-		my $filename = shift;
-		my $encoding = shift;
-		_file_contains(like => "contains", $encoding, $filename, @_);
-	}
-sub file_contains_encoded_unlike
-	{
-		local $Test::Builder::Level = $Test::Builder::Level + 1;
-		my $filename = shift;
-		my $encoding = shift;
-		_file_contains(unlike => "doesn't contain", $encoding, $filename, @_);
+sub file_contains_utf8_unlike {
+	local $Test::Builder::Level = $Test::Builder::Level + 1;
+	_file_contains(unlike => "doesn't contain", 'UTF-8', @_);
 	}
 
-sub _file_contains
-	{
+sub file_contains_encoded_like {
+	local $Test::Builder::Level = $Test::Builder::Level + 1;
+	my $filename = shift;
+	my $encoding = shift;
+	_file_contains(like => "contains", $encoding, $filename, @_);
+	}
+
+sub file_contains_encoded_unlike {
+	local $Test::Builder::Level = $Test::Builder::Level + 1;
+	my $filename = shift;
+	my $encoding = shift;
+	_file_contains(unlike => "doesn't contain", $encoding, $filename, @_);
+	}
+
+sub _file_contains {
 	my $method   = shift;
 	my $verb     = shift;
 	my $encoding = shift;
@@ -641,13 +639,11 @@ sub _file_contains
 	my $name     = shift;
 
 	my (@patterns, %patterns);
-	if (ref $patterns eq 'ARRAY')
-		{
+	if (ref $patterns eq 'ARRAY') {
 		@patterns = @$patterns;
 		%patterns = map { $_ => $name || "$filename $verb $_" } @patterns;
 		}
-		else
-		{
+	else {
 		@patterns = ($patterns);
 		%patterns = ( $patterns => $name || "$filename $verb $patterns" );
 		}
@@ -656,14 +652,17 @@ sub _file_contains
 	# test name as the name
 	$name = $patterns{$patterns[0]};
 
-	unless( -e $filename )
-		{
+	unless( -e $filename ) {
 		$Test->diag( "File [$filename] does not exist!" );
 		return $Test->ok(0, $name);
 		}
 
-	unless( -r $filename )
-		{
+	unless( -f $filename ) {
+		my $caller = ( caller(0) )[3];
+		$Test->diag( "File [$filename] is a directory, which is deprecated for $caller" );
+		}
+
+	unless( -r $filename ) {
 		$Test->diag( "File [$filename] is not readable!" );
 		return $Test->ok(0, $name);
 		}
@@ -671,47 +670,42 @@ sub _file_contains
 	# do the slurp
 	my $file_contents;
 	{
-	unless (open(FH, $filename))
-		{
+	unless (open(FH, $filename)) {
 		$Test->diag( "Could not open [$filename]: \$! is [$!]!" );
 		return $Test->ok( 0, $name );
 		}
 
 	if (defined $encoding) {
 		binmode FH, ":encoding($encoding)";
-	}
+		}
 
 	local $/ = undef;
 	$file_contents = <FH>;
 	close FH;
 	}
 
-	foreach my $p (@patterns)
-		{
+	foreach my $p (@patterns) {
 		$Test->$method($file_contents, $p, $patterns{$p});
 		}
 	}
 
 =item file_readable_ok( FILENAME [, NAME ] )
 
-Ok if the file exists and is readable, not ok
-if the file does not exist or is not readable.
+Ok if the file exists and is readable, not ok if the file does not
+exist or is not readable.
 
 =cut
 
-sub file_readable_ok
-	{
+sub file_readable_ok {
 	my $filename = _normalize( shift );
 	my $name     = shift || "$filename is readable";
 
 	my $ok = -r $filename;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag( "File [$filename] is not readable!" );
 		$Test->ok(0, $name);
 		}
@@ -719,24 +713,21 @@ sub file_readable_ok
 
 =item file_not_readable_ok( FILENAME [, NAME ] )
 
-Ok if the file exists and is not readable, not ok
-if the file does not exist or is readable.
+Ok if the file exists and is not readable, not ok if the file does not
+exist or is readable.
 
 =cut
 
-sub file_not_readable_ok
-	{
+sub file_not_readable_ok {
 	my $filename = _normalize( shift );
 	my $name     = shift || "$filename is not readable";
 
 	my $ok = not -r $filename;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag( "File [$filename] is readable!" );
 		$Test->ok(0, $name);
 		}
@@ -754,26 +745,22 @@ still works but there's a function with the correct spelling too.
 
 =cut
 
-sub file_writeable_ok
-	{
+sub file_writeable_ok {
 	carp "file_writeable_ok is now file_writable_ok";
 
 	&file_writable_ok;
 	}
 
-sub file_writable_ok
-	{
+sub file_writable_ok {
 	my $filename = _normalize( shift );
 	my $name     = shift || "$filename is writable";
 
 	my $ok = -w $filename;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag( "File [$filename] is not writable!" );
 		$Test->ok(0, $name);
 		}
@@ -791,26 +778,22 @@ That still works but there's a function with the correct spelling too.
 
 =cut
 
-sub file_not_writeable_ok
-	{
+sub file_not_writeable_ok {
 	carp "file_not_writeable_ok is now file_not_writable_ok";
 
 	&file_not_writable_ok;
 	}
 
-sub file_not_writable_ok
-	{
+sub file_not_writable_ok {
 	my $filename = _normalize( shift );
 	my $name     = shift || "$filename is not writable";
 
 	my $ok = not -w $filename;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag("File [$filename] is writable!");
 		$Test->ok(0, $name);
 		}
@@ -818,18 +801,16 @@ sub file_not_writable_ok
 
 =item file_executable_ok( FILENAME [, NAME ] )
 
-Ok if the file exists and is executable, not ok
-if the file does not exist or is not executable.
+Ok if the file exists and is executable, not ok if the file does not
+exist or is not executable.
 
-This test automatically skips if it thinks it is on a
-Windows platform.
+This test automatically skips if it thinks it is on a Windows
+platform.
 
 =cut
 
-sub file_executable_ok
-	{
-	if( _win32() )
-		{
+sub file_executable_ok {
+	if( _win32() ) {
 		$Test->skip( "file_executable_ok doesn't work on Windows!" );
 		return;
 		}
@@ -839,12 +820,10 @@ sub file_executable_ok
 
 	my $ok = -x $filename;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag("File [$filename] is not executable!");
 		$Test->ok(0, $name);
 		}
@@ -852,18 +831,16 @@ sub file_executable_ok
 
 =item file_not_executable_ok( FILENAME [, NAME ] )
 
-Ok if the file exists and is not executable, not ok
-if the file does not exist or is executable.
+Ok if the file exists and is not executable, not ok if the file does
+not exist or is executable.
 
-This test automatically skips if it thinks it is on a
-Windows platform.
+This test automatically skips if it thinks it is on a Windows
+platform.
 
 =cut
 
-sub file_not_executable_ok
-	{
-	if( _win32() )
-		{
+sub file_not_executable_ok {
+	if( _win32() ) {
 		$Test->skip( "file_not_executable_ok doesn't work on Windows!" );
 		return;
 		}
@@ -873,12 +850,10 @@ sub file_not_executable_ok
 
 	my $ok = not -x $filename;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag("File [$filename] is executable!");
 		$Test->ok(0, $name);
 		}
@@ -886,20 +861,18 @@ sub file_not_executable_ok
 
 =item file_mode_is( FILENAME, MODE [, NAME ] )
 
-Ok if the file exists and the mode matches, not ok
-if the file does not exist or the mode does not match.
+Ok if the file exists and the mode matches, not ok if the file does
+not exist or the mode does not match.
 
-This test automatically skips if it thinks it is on a
-Windows platform.
+This test automatically skips if it thinks it is on a Windows
+platform.
 
 Contributed by Shawn Sorichetti C<< <ssoriche@coloredblocks.net> >>
 
 =cut
 
-sub file_mode_is
-	{
-	if( _win32() )
-		{
+sub file_mode_is {
+	if( _win32() ) {
 		$Test->skip( "file_mode_is doesn't work on Windows!" );
 		return;
 		}
@@ -911,12 +884,10 @@ sub file_mode_is
 
 	my $ok = -e $filename && ((stat($filename))[2] & 07777) == $mode;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag(sprintf("File [%s] mode is not %04o!", $filename, $mode) );
 		$Test->ok(0, $name);
 		}
@@ -924,20 +895,18 @@ sub file_mode_is
 
 =item file_mode_isnt( FILENAME, MODE [, NAME ] )
 
-Ok if the file exists and mode does not match, not ok
-if the file does not exist or mode does match.
+Ok if the file exists and mode does not match, not ok if the file does
+not exist or mode does match.
 
-This test automatically skips if it thinks it is on a
-Windows platform.
+This test automatically skips if it thinks it is on a Windows
+platform.
 
 Contributed by Shawn Sorichetti C<< <ssoriche@coloredblocks.net> >>
 
 =cut
 
-sub file_mode_isnt
-	{
-	if( _win32() )
-		{
+sub file_mode_isnt {
+	if( _win32() ) {
 		$Test->skip( "file_mode_isnt doesn't work on Windows!" );
 		return;
 		}
@@ -949,12 +918,10 @@ sub file_mode_isnt
 
 	my $ok = not (-e $filename && ((stat($filename))[2] & 07777) == $mode);
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag(sprintf("File [%s] mode is %04o!",$filename,$mode));
 		$Test->ok(0, $name);
 		}
@@ -963,20 +930,18 @@ sub file_mode_isnt
 =item file_mode_has( FILENAME, MODE [, NAME ] )
 
 Ok if the file exists and has all the bits in mode turned on, not ok
-if the file does not exist or the mode does not match.  That is,
-C<< FILEMODE & MODE == MODE >> must be true.
+if the file does not exist or the mode does not match.  That is, C<<
+FILEMODE & MODE == MODE >> must be true.
 
-This test automatically skips if it thinks it is on a
-Windows platform.
+This test automatically skips if it thinks it is on a Windows
+platform.
 
 Contributed by Ricardo Signes C<< <rjbs@cpan.org> >>
 
 =cut
 
-sub file_mode_has
-	{
-	if( _win32() )
-		{
+sub file_mode_has {
+	if( _win32() ) {
 		$Test->skip( "file_mode_has doesn't work on Windows!" );
 		return;
 		}
@@ -990,12 +955,10 @@ sub file_mode_has
 	my $gotmode = $present ? (stat($filename))[2] : undef;
 	my $ok      = $present && ($gotmode & $mode) == $mode;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		my $missing = ($gotmode ^ $mode) & $mode;
 		$Test->diag(sprintf("File [%s] mode is missing component %04o!", $filename, $missing) );
 		$Test->ok(0, $name);
@@ -1015,10 +978,8 @@ Contributed by Ricardo Signes C<< <rjbs@cpan.org> >>
 
 =cut
 
-sub file_mode_hasnt
-	{
-	if( _win32() )
-		{
+sub file_mode_hasnt {
+	if( _win32() ) {
 		$Test->skip( "file_mode_hasnt doesn't work on Windows!" );
 		return;
 		}
@@ -1032,12 +993,10 @@ sub file_mode_hasnt
 	my $gotmode = $present ? (stat($filename))[2] : undef;
 	my $ok      = $present && ($gotmode & $mode) == 0;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		my $bad = $gotmode & $mode;
 		$Test->diag(sprintf("File [%s] mode has forbidden component %04o!", $filename, $bad) );
 		$Test->ok(0, $name);
@@ -1052,10 +1011,8 @@ not support symlinks. If the file does not exist, the test fails.
 
 =cut
 
-sub file_is_symlink_ok
-	{
-	if( _no_symlinks_here() )
-		{
+sub file_is_symlink_ok {
+	if( _no_symlinks_here() ) {
 		$Test->skip(
 			"file_is_symlink_ok doesn't work on systems without symlinks!" );
 		return;
@@ -1064,12 +1021,10 @@ sub file_is_symlink_ok
 	my $file = shift;
 	my $name = shift || "$file is a symlink";
 
-	if( -l $file )
-		{
+	if( -l $file ) {
 		$Test->ok(1, $name)
 		}
-	else
-		{
+	else {
 		$Test->diag( "File [$file] is not a symlink!" );
 		$Test->ok(0, $name);
 		}
@@ -1084,10 +1039,8 @@ support symlinks. If the file does not exist, the test fails.
 
 =cut
 
-sub symlink_target_exists_ok
-	{
-	if( _no_symlinks_here() )
-		{
+sub symlink_target_exists_ok {
+	if( _no_symlinks_here() ) {
 		$Test->skip(
 			"symlink_target_exists_ok doesn't work on systems without symlinks!"
 			);
@@ -1104,15 +1057,13 @@ sub symlink_target_exists_ok
 		return $Test->ok( 0, $name );
 		}
 
-	unless( -e $dest )
-		{
+	unless( -e $dest ) {
 		$Test->diag( "Symlink [$file] points to non-existent target [$dest]!" );
 		return $Test->ok( 0, $name );
 		}
 
 	my $actual = readlink( $file );
-	unless( $dest eq $actual )
-		{
+	unless( $dest eq $actual ) {
 		$Test->diag(
 			"Symlink [$file] points to\n" .
 			"         got: $actual\n" .
@@ -1134,8 +1085,7 @@ support symlinks. If the file does not exist, the test fails.
 
 sub symlink_target_dangles_ok
 	{
-	if( _no_symlinks_here() )
-		{
+	if( _no_symlinks_here() ) {
 		$Test->skip(
 			"symlink_target_dangles_ok doesn't work on systems without symlinks!" );
 		return;
@@ -1145,14 +1095,12 @@ sub symlink_target_dangles_ok
 	my $dest = readlink( $file );
 	my $name = shift || "$file is a symlink";
 
-	unless( -l $file )
-		{
+	unless( -l $file ) {
 		$Test->diag( "File [$file] is not a symlink!" );
 		return $Test->ok( 0, $name );
 		}
 
-	if( -e $dest )
-		{
+	if( -e $dest ) {
 		$Test->diag(
 			"Symlink [$file] points to existing file [$dest] but shouldn't!" );
 		return $Test->ok( 0, $name );
@@ -1169,10 +1117,8 @@ If the file does not exist, the test fails.
 
 =cut
 
-sub symlink_target_is
-	{
-	if( _no_symlinks_here() )
-		{
+sub symlink_target_is {
+	if( _no_symlinks_here() ) {
 		$Test->skip(
 			"symlink_target_is doesn't work on systems without symlinks!" );
 		return;
@@ -1182,8 +1128,7 @@ sub symlink_target_is
 	my $dest = shift;
 	my $name = shift || "symlink $file points to $dest";
 
-	unless( -l $file )
-		{
+	unless( -l $file ) {
 		$Test->diag( "File [$file] is not a symlink!" );
 		return $Test->ok( 0, $name );
 		}
@@ -1191,19 +1136,16 @@ sub symlink_target_is
 	my $actual_dest = readlink( $file );
 	my $link_error  = $!;
 
-	unless( defined $actual_dest )
-		{
+	unless( defined $actual_dest ) {
 		$Test->diag( "Symlink [$file] does not have a defined target!" );
 		$Test->diag( "readlink error: $link_error" ) if defined $link_error;
 		return $Test->ok( 0, $name );
 		}
 
-	if( $dest eq $actual_dest )
-		{
+	if( $dest eq $actual_dest ) {
 		$Test->ok( 1, $name );
 		}
-	else
-		{
+	else {
 		$Test->ok( 0, $name );
 		$Test->diag("       got: $actual_dest" );
 		$Test->diag("  expected: $dest" );
@@ -1218,10 +1160,8 @@ symlinks. If the file does not exist, the test fails.
 
 =cut
 
-sub symlink_target_is_absolute_ok
-	{
-	if( _no_symlinks_here() )
-		{
+sub symlink_target_is_absolute_ok {
+	if( _no_symlinks_here() ) {
 		$Test->skip(
 			"symlink_target_exists_ok doesn't work on systems without symlinks" );
 		return;
@@ -1260,25 +1200,21 @@ Contributed by Buddy Burden C<< <barefoot@cpan.org> >>.
 
 =cut
 
-sub dir_exists_ok
-	{
+sub dir_exists_ok {
 	my $filename = _normalize( shift );
 	my $name     = shift || "$filename is a directory";
 
-	unless( -e $filename )
-		{
-		$Test->diag( "File [$filename] does not exist!" );
+	unless( -e $filename ) {
+		$Test->diag( "Directory [$filename] does not exist!" );
 		return $Test->ok(0, $name);
 		}
 
 	my $ok = -d $filename;
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag( "File [$filename] exists but is not a directory!" );
 		$Test->ok(0, $name);
 		}
@@ -1293,26 +1229,22 @@ Contributed by Buddy Burden C<< <barefoot@cpan.org> >>.
 
 =cut
 
-sub dir_contains_ok
-	{
+sub dir_contains_ok {
 	my $dirname  = _normalize( shift );
 	my $filename = _normalize( shift );
 	my $name     = shift || "directory $dirname contains file $filename";
 
-	unless( -d $dirname )
-		{
+	unless( -d $dirname ) {
 		$Test->diag( "Directory [$dirname] does not exist!" );
 		return $Test->ok(0, $name);
 		}
 
 	my $ok = -e File::Spec->catfile($dirname, $filename);
 
-	if( $ok )
-		{
+	if( $ok ) {
 		$Test->ok(1, $name);
 		}
-	else
-		{
+	else {
 		$Test->diag( "File [$filename] does not exist in directory $dirname!" );
 		$Test->ok(0, $name);
 		}
@@ -1327,8 +1259,7 @@ does not exist.
 
 =cut
 
-sub link_count_is_ok
-	{
+sub link_count_is_ok {
 	my $file   = shift;
 	my $count  = int( 0 + shift );
 
@@ -1336,8 +1267,7 @@ sub link_count_is_ok
 
 	my $actual = ( stat $file )[3];
 
-	unless( $actual == $count )
-		{
+	unless( $actual == $count ) {
 		$Test->diag(
 			"File [$file] points has [$actual] links: expected [$count]!" );
 		return $Test->ok( 0, $name );
@@ -1354,8 +1284,7 @@ if the file has at least one link.
 
 =cut
 
-sub link_count_gt_ok
-	{
+sub link_count_gt_ok {
 	my $file   = shift;
 	my $count  = int( 0 + shift );
 
@@ -1363,8 +1292,7 @@ sub link_count_gt_ok
 
 	my $actual = (stat $file )[3];
 
-	unless( $actual > $count )
-		{
+	unless( $actual > $count ) {
 		$Test->diag(
 			"File [$file] points has [$actual] links: ".
 			"expected more than [$count]!" );
@@ -1382,8 +1310,7 @@ if the file has at least one link.
 
 =cut
 
-sub link_count_lt_ok
-	{
+sub link_count_lt_ok {
 	my $file   = shift;
 	my $count  = int( 0 + shift );
 
@@ -1391,8 +1318,7 @@ sub link_count_lt_ok
 
 	my $actual = (stat $file )[3];
 
-	unless( $actual < $count )
-		{
+	unless( $actual < $count ) {
 		$Test->diag(
 			"File [$file] points has [$actual] links: ".
 			"expected less than [$count]!" );
@@ -1406,12 +1332,10 @@ sub link_count_lt_ok
 # owner_is, owner_isnt, group_is and group_isnt are almost
 # identical in the beginning, so I'm writing a skeleton they can all use.
 # I can't think of a better name...
-sub _dm_skeleton
-	{
+sub _dm_skeleton {
 	no warnings 'uninitialized';
 
-	if( _obviously_non_multi_user() )
-		{
+	if( _obviously_non_multi_user() ) {
 		my $calling_sub = (caller(1))[3];
 		$Test->skip( $calling_sub . " only works on a multi-user OS!" );
 		return 'skip';
@@ -1421,14 +1345,12 @@ sub _dm_skeleton
 	my $testing_for   = shift;
 	my $name          = shift;
 
-	unless( defined $filename )
-		{
+	unless( defined $filename ) {
 		$Test->diag( "File name not specified!" );
 		return $Test->ok( 0, $name );
 		}
 
-	unless( -e $filename )
-		{
+	unless( -e $filename ) {
 		$Test->diag( "File [$filename] does not exist!" );
 		return $Test->ok( 0, $name );
 		}
@@ -1446,8 +1368,7 @@ Contributed by Dylan Martin
 
 =cut
 
-sub owner_is
-	{
+sub owner_is {
 	my $filename      = shift;
 	my $owner         = shift;
 	my $name          = shift || "$filename belongs to $owner";
@@ -1457,16 +1378,14 @@ sub owner_is
 	return $err if defined($err);
 
 	my $owner_uid = _get_uid( $owner );
-	unless( defined $owner_uid )
-		{
+	unless( defined $owner_uid ) {
 		$Test->diag("User [$owner] does not exist on this system!");
 		return $Test->ok( 0, $name );
 		}
 
 	my $file_uid = ( stat $filename )[4];
 
-	unless( defined $file_uid )
-		{
+	unless( defined $file_uid ) {
 		$Test->skip("stat failed to return owner uid for $filename!");
 		return;
 		}
@@ -1474,8 +1393,7 @@ sub owner_is
 	return $Test->ok( 1, $name ) if $file_uid == $owner_uid;
 
 	my $real_owner = ( getpwuid $file_uid )[0];
-	unless( defined $real_owner )
-		{
+	unless( defined $real_owner ) {
 		$Test->diag("File does not belong to $owner!");
 		return $Test->ok( 0, $name );
 		}
@@ -1495,8 +1413,7 @@ Contributed by Dylan Martin
 
 =cut
 
-sub owner_isnt
-	{
+sub owner_isnt {
 	my $filename      = shift;
 	my $owner         = shift;
 	my $name          = shift || "$filename doesn't belong to $owner";
@@ -1506,8 +1423,7 @@ sub owner_isnt
 	return $err if defined($err);
 
 	my $owner_uid = _get_uid( $owner );
-	unless( defined $owner_uid )
-		{
+	unless( defined $owner_uid ) {
 		return $Test->ok( 1, $name );
 		}
 
@@ -1531,8 +1447,7 @@ Contributed by Dylan Martin
 
 =cut
 
-sub group_is
-	{
+sub group_is {
 	my $filename      = shift;
 	my $group         = shift;
 	my $name          = ( shift || "$filename belongs to group $group" );
@@ -1542,16 +1457,14 @@ sub group_is
 	return $err if defined($err);
 
 	my $group_gid = _get_gid( $group );
-	unless( defined $group_gid )
-		{
+	unless( defined $group_gid ) {
 		$Test->diag("Group [$group] does not exist on this system!");
 		return $Test->ok( 0, $name );
 		}
 
 	my $file_gid  = ( stat $filename )[5];
 
-	unless( defined $file_gid )
-		{
+	unless( defined $file_gid ) {
 		$Test->skip("stat failed to return group gid for $filename!");
 		return;
 		}
@@ -1559,8 +1472,7 @@ sub group_is
 	return $Test->ok( 1, $name ) if $file_gid == $group_gid;
 
 	my $real_group = ( getgrgid $file_gid )[0];
-	unless( defined $real_group )
-		{
+	unless( defined $real_group ) {
 		$Test->diag("File does not belong to $group!");
 		return $Test->ok( 0, $name );
 		}
@@ -1582,8 +1494,7 @@ Contributed by Dylan Martin
 
 =cut
 
-sub group_isnt
-	{
+sub group_isnt {
 	my $filename      = shift;
 	my $group         = shift;
 	my $name          = shift || "$filename does not belong to group $group";
@@ -1595,8 +1506,7 @@ sub group_isnt
 	my $group_gid = _get_gid( $group );
 	my $file_gid  = ( stat $filename )[5];
 
-	unless( defined $file_gid )
-		{
+	unless( defined $file_gid ) {
 		$Test->skip("stat failed to return group gid for $filename!");
 		return;
 		}
@@ -1607,36 +1517,30 @@ sub group_isnt
 		return $Test->ok( 0, $name );
 	}
 
-sub _get_uid
-	{
+sub _get_uid {
 	my $owner = shift;
 	my $owner_uid;
 
-	if ($owner =~ /^\d+/)
-		{
+	if ($owner =~ /^\d+/) {
 		$owner_uid = $owner;
 		$owner = ( getpwuid $owner )[0];
 		}
-	else
-		{
+	else {
 		$owner_uid = (getpwnam($owner))[2];
 		}
 
 	$owner_uid;
 	}
 
-sub _get_gid
-	{
+sub _get_gid {
 	my $group = shift;
 	my $group_uid;
 
-	if ($group =~ /^\d+/)
-		{
+	if ($group =~ /^\d+/) {
 		$group_uid = $group;
 		$group = ( getgrgid $group )[0];
 		}
-	else
-		{
+	else {
 		$group_uid = (getgrnam($group))[2];
 		}
 
@@ -1652,8 +1556,7 @@ returns failure. If stat() fails, the test is skipped.
 
 =cut
 
-sub file_mtime_age_ok
-	{
+sub file_mtime_age_ok {
 	my $filename    = shift;
 	my $within_secs = int shift || 0;
 	my $name        = shift || "$filename mtime within $within_secs seconds of current time";
@@ -1677,8 +1580,7 @@ this test is skipped. If FILE does not exist, this test fails.
 
 =cut
 
-sub file_mtime_gt_ok
-	{
+sub file_mtime_gt_ok {
 	my $filename    = shift;
 	my $time        = int shift;
 	my $name        = shift || "$filename mtime is greater than unix timestamp $time";
@@ -1700,8 +1602,7 @@ this test is skipped. If FILE does not exist, this test fails.
 
 =cut
 
-sub file_mtime_lt_ok
-	{
+sub file_mtime_lt_ok {
 	my $filename = shift;
 	my $time = int shift;
 	my $name = shift || "$filename mtime less than unix timestamp $time";
@@ -1728,27 +1629,23 @@ sub file_mtime_lt_ok
 #  0        - failure (file doesn't exist etc)
 #  filetime - on success, time requested provided by stat
 #
-sub _stat_file
-	{
+sub _stat_file {
 	my $filename    = _normalize( shift );
 	my $attr_pos    = shift;
 
-	unless( defined $filename )
-		{
+	unless( defined $filename ) {
 		$Test->diag( "Filename not specified!" );
 		return 0;
 		}
 
-	unless( -e $filename )
-		{
+	unless( -e $filename ) {
 		$Test->diag( "Filename [$filename] does not exist!" );
 		return 0;
 		}
 
 	my $filetime = ( stat($filename) )[$attr_pos];
 
-	unless( $filetime )
-		{
+	unless( $filetime ) {
 		$Test->diag( "stat of $filename failed" );
 		return -1; #skip on stat failure
 		}
@@ -1773,6 +1670,8 @@ sub _stat_file
 L<Test::Builder>,
 L<Test::More>
 
+If you are using the new C<Test2> stuff, see L<Test2::Tool::File>.
+
 =head1 SOURCE AVAILABILITY
 
 This module is in Github:
@@ -1801,13 +1700,15 @@ C<file_contains_unlike>.
 xmikew C<< <https://github.com/xmikew> >> provided the C<mtime_age>
 stuff.
 
+Torbjørn Lindahl is working on L<Test2::Tools::File> and we're
+working together to align our interfaces.
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright © 2002-2020, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the Artistic License 2.0
 
 =cut
 
